## Example

```Python
import colorterminal

print(colorterminal.ColorText.RED + 'Hello' + colorterminal.ColorText.PURPLE + ' World')
```

#### Output

![Output](https://i.ibb.co/cDvN6Z4/2-5413863330953562736.png)